"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bindAgileInstances = void 0;
const core_1 = require("@agile-ts/core");
const utils_1 = require("@agile-ts/utils");
function bindAgileInstances(deps, agile, vueComponent, observerType) {
    let depsWithoutIndicator = [];
    let depsWithIndicator;
    if (utils_1.isValidObject(deps)) {
        depsWithIndicator = formatDepsWithIndicator(deps, observerType);
    }
    else {
        const response = formatDepsWithNoSafeIndicator(deps, observerType);
        depsWithIndicator = response.depsWithIndicator;
        depsWithoutIndicator = response.depsWithoutIndicator;
    }
    if (depsWithoutIndicator.length > 0) {
        agile.subController.subscribe(vueComponent, depsWithoutIndicator, {
            waitForMount: false,
        });
    }
    if (depsWithIndicator) {
        return agile.subController.subscribe(vueComponent, depsWithIndicator, {
            waitForMount: false,
        }).props;
    }
    return {};
}
exports.bindAgileInstances = bindAgileInstances;
const formatDepsWithNoSafeIndicator = (deps, observerType) => {
    const depsArray = core_1.extractRelevantObservers(utils_1.normalizeArray(deps), observerType);
    const depsWithIndicator = {};
    let depsWithoutIndicator = depsArray.filter((dep) => dep !== undefined);
    depsWithoutIndicator = depsWithoutIndicator.filter((dep) => {
        if (dep && dep['key'] != null) {
            depsWithIndicator[dep['key']] = dep;
            return false;
        }
        return true;
    });
    return {
        depsWithIndicator,
        depsWithoutIndicator,
    };
};
const formatDepsWithIndicator = (deps, observerType) => {
    const depsObject = core_1.extractRelevantObservers(deps, observerType);
    const depsWithIndicator = {};
    for (const key in depsObject) {
        const observer = depsObject[key];
        if (observer != null)
            depsWithIndicator[key] = observer;
    }
    return depsWithIndicator;
};
