import { extractRelevantObservers, } from '@agile-ts/core';
import { isValidObject, normalizeArray } from '@agile-ts/utils';
export function bindAgileInstances(deps, agile, vueComponent, observerType) {
    let depsWithoutIndicator = [];
    let depsWithIndicator;
    if (isValidObject(deps)) {
        depsWithIndicator = formatDepsWithIndicator(deps, observerType);
    }
    else {
        const response = formatDepsWithNoSafeIndicator(deps, observerType);
        depsWithIndicator = response.depsWithIndicator;
        depsWithoutIndicator = response.depsWithoutIndicator;
    }
    if (depsWithoutIndicator.length > 0) {
        agile.subController.subscribe(vueComponent, depsWithoutIndicator, {
            waitForMount: false,
        });
    }
    if (depsWithIndicator) {
        return agile.subController.subscribe(vueComponent, depsWithIndicator, {
            waitForMount: false,
        }).props;
    }
    return {};
}
const formatDepsWithNoSafeIndicator = (deps, observerType) => {
    const depsArray = extractRelevantObservers(normalizeArray(deps), observerType);
    const depsWithIndicator = {};
    let depsWithoutIndicator = depsArray.filter((dep) => dep !== undefined);
    depsWithoutIndicator = depsWithoutIndicator.filter((dep) => {
        if (dep && dep['key'] != null) {
            depsWithIndicator[dep['key']] = dep;
            return false;
        }
        return true;
    });
    return {
        depsWithIndicator,
        depsWithoutIndicator,
    };
};
const formatDepsWithIndicator = (deps, observerType) => {
    const depsObject = extractRelevantObservers(deps, observerType);
    const depsWithIndicator = {};
    for (const key in depsObject) {
        const observer = depsObject[key];
        if (observer != null)
            depsWithIndicator[key] = observer;
    }
    return depsWithIndicator;
};
