import { Integration, Integrations } from '@agile-ts/core';
import Vue from 'vue';
import { bindAgileInstances } from './bindAgileInstances';
const vueIntegration = new Integration({
    key: 'vue',
    frameworkInstance: Vue,
    updateMethod: (componentInstance, updatedData) => {
        const componentData = componentInstance.$data;
        for (const key of Object.keys(updatedData)) {
            if (Object.prototype.hasOwnProperty.call(componentData, key)) {
                componentData.sharedState[key] = updatedData[key];
            }
            else {
                Vue.set(componentData.sharedState, key, updatedData[key]);
            }
        }
    },
    bind: (agile) => {
        Vue.use({
            install: (vue) => {
                vue.mixin({
                    created: function () {
                        this.$agile = agile;
                    },
                    methods: {
                        bindAgileInstances: function (deps) {
                            var _a;
                            return {
                                sharedState: Object.assign(Object.assign({}, (((_a = this === null || this === void 0 ? void 0 : this.$data) === null || _a === void 0 ? void 0 : _a.sharedState) || {})), bindAgileInstances(deps, agile, this)),
                            };
                        },
                        bindAgileValues: function (deps) {
                            var _a;
                            return {
                                sharedState: Object.assign(Object.assign({}, (((_a = this === null || this === void 0 ? void 0 : this.$data) === null || _a === void 0 ? void 0 : _a.sharedState) || {})), bindAgileInstances(deps, agile, this, 'value')),
                            };
                        },
                        bindAgileOutputs: function (deps) {
                            var _a;
                            return {
                                sharedState: Object.assign(Object.assign({}, (((_a = this === null || this === void 0 ? void 0 : this.$data) === null || _a === void 0 ? void 0 : _a.sharedState) || {})), bindAgileInstances(deps, agile, this, 'output')),
                            };
                        },
                    },
                });
            },
        });
        return Promise.resolve(true);
    },
});
Integrations.addInitialIntegration(vueIntegration);
export default vueIntegration;
